==> haskell-hls-retrie-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-FoVpySbLUysCbWSkdahKT5
key:                  hls-retrie-plugin-2.1.0.0-FoVpySbLUysCbWSkdahKT5
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bdd77c32c4deacdb4494ed41f1cb9e9f
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-FoVpySbLUysCbWSkdahKT5
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-KxrHBQWVwMp2M62XitBte8 ghc-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    hls-refactor-plugin-2.1.0.0-1mgIyR2L99XJYvvY3SkUi6
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA mtl-2.2.2
    retrie-1.2.3-1y6GbD5JAzcAnLlEmWsfCh
    safe-exceptions-0.1.7.4-JJtencRNvfPAVPHD6bpNCc stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-retrie-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-KTecV8iETRDJElHQvBokJS
key:                  hls-retrie-plugin-2.1.0.0-KTecV8iETRDJElHQvBokJS
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c8421583a27b2abe5a035f7411457689
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-KTecV8iETRDJElHQvBokJS
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E ghc-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    hls-refactor-plugin-2.1.0.0-ExDUElgsYmt9j5A89B9r6p
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400 mtl-2.2.2
    retrie-1.2.3-4xmNpLWUS55A2ToWNKattd
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
